import { NuxtOptions, Module } from '@nuxt/types';
import SpeedMeasurePlugin from 'speed-measure-webpack-plugin';
import { Configuration } from 'webpack';
import { ExtendFunctionContext } from '@nuxt/types/config/module';
import { LoaderOptions, MinifyPluginOptions } from 'esbuild-loader/dist/interfaces';
import { Consola } from 'consola';

declare type RiskProfile = 'risky' | 'experimental' | 'safe';
declare type MeasureMode = 'client' | 'server' | 'modern' | 'all';
interface FeatureFlags {
    esbuildLoader: boolean;
    esbuildMinifier: boolean;
    imageFileLoader: boolean;
    webpackOptimisations: boolean;
    postcssNoPolyfills: boolean;
    cacheLoader: boolean;
    hardSourcePlugin: boolean;
    parallelPlugin: boolean;
}
interface OptimisationArgs {
    nuxtOptions: NuxtOptions;
    options: ModuleOptions;
    config: Configuration;
    logger: Consola;
    env: ExtendFunctionContext;
}
interface ModuleOptions {
    measureMode: MeasureMode;
    measure: boolean | SpeedMeasurePlugin.Options;
    profile: RiskProfile | false;
    esbuildLoaderOptions: LoaderOptions | ((args: OptimisationArgs) => LoaderOptions);
    esbuildMinifyOptions: MinifyPluginOptions | ((args: OptimisationArgs) => MinifyPluginOptions);
    features: FeatureFlags;
}

declare const buildOptimisationsModule: Module<ModuleOptions>;

export default buildOptimisationsModule;
